library(ggplot2)
library(scales)
library(ez)
library(reshape2)
library(grid)

title.text<-element_text(size=12, face="bold")
tick.text<-element_text(size=10)

dfEng=read.csv("F:/sound sorting data/engines/myAffect_engines.csv", header = TRUE, sep = ",")
dfDog=read.csv("F:/sound sorting data/dogs/data/myAffect_dog.csv", header = TRUE, sep = ",")
dfNat=read.csv("F:/sound sorting data/nature sounds/myAffect_nature.csv", header = TRUE, sep = ",")
dfMan=read.csv("F:/sound sorting data/manmade/myAffect_manmade.csv", header = TRUE, sep = ",")
dfTop=read.csv("F:/sound sorting data/brown sounds/myAffect_brown.csv", header = TRUE, sep = ",")
dfTop2=read.csv("F:/sound sorting data/brown _nowords/myAffect.csv", header = TRUE, sep = ",")

Top<-c(sum(dfTop$type=="signal")/length(dfTop[,1]),sum(dfTop$type=="source")/length(dfTop[,1]),sum(dfTop$type=="affect")/length(dfTop[,1]))
Nature<-c(sum(dfNat$type=="signal")/length(dfNat[,1]),sum(dfNat$type=="source")/length(dfNat[,1]),sum(dfNat$type=="affect")/length(dfNat[,1]))
Manmade<-c(sum(dfMan$type=="signal")/length(dfMan[,1]),sum(dfMan$type=="source")/length(dfMan[,1]),sum(dfMan$type=="affect")/length(dfMan[,1]))
Dog<-c(sum(dfDog$type=="signal")/length(dfDog[,1]),sum(dfDog$type=="source")/length(dfDog[,1]),sum(dfDog$type=="affect")/length(dfDog[,1]))
Engine<-c(sum(dfEng$type=="signal")/length(dfEng[,1]),sum(dfEng$type=="source")/length(dfEng[,1]),sum(dfEng$type=="affect")/length(dfEng[,1]))
Top2<-c(sum(dfTop2$Type=="acoustic")/length(dfTop2[,1]),sum(dfTop2$Type=="source-event")/length(dfTop2[,1]),sum(dfTop2$Type=="subjective-state")/length(dfTop2[,1]))


Type<-c("Acoustic", "Source-event", "Subjective-state")
Top2<-Top2*100
Top<-Top*100
Nature<-Nature*100
Manmade<-Manmade*100
Dog<-Dog*100
Engine<-Engine*100

df=data.frame(Type, Nature, Manmade, Dog, Engine)
datm <- melt(df)
datm$Type<-as.factor(datm$Type)

p1<-ggplot(datm,aes(x = variable, y = value,fill = Type)) + 
	geom_bar(position = "fill",stat = "identity") +
#	colScaleCol+
#	scale_fill_distiller(palette = "RdYlGn")+
	scale_y_continuous(labels=percent_format())+
	theme_bw()+
	labs(x="Level", y="Percentage")+
	scale_fill_manual(values = c("Affect-judgement"="deepskyblue","Signal"="chartreuse4","Source"= "firebrick"))+
	theme(
	axis.title=title.text,
	axis.text=tick.text,
	legend.text=title.text,
	panel.grid	= element_blank(),
	legend.title=element_blank(),
	legend.background = element_rect(fill = "white")
)

contTab<-xtabs(datm$value~datm$Type+datm$variable, datm)

#Just nat  and man
datmMidMan<-subset(datm, datm$variable=="Manmade")
datmMidNat<-subset(datm, datm$variable=="Nature")
datmMid<-rbind(datmMidMan,datmMidNat)

contTabMid<-xtabs(value~Type+droplevels(variable), datmMid)
CrossTable(contTabMid, fisher=TRUE, chisq=TRUE, expected=TRUE, sresid=TRUE, format="SPSS")


library(gmodels)
#All sounds
CrossTable(contTab, fisher=TRUE, chisq=TRUE, expected=TRUE, sresid=TRUE, format="SPSS")

#Top v Mid
Middle<-(df$Nature+df$Manmade)/2
dfTopMid=data.frame(Type, Top, Middle)
datmTopMid <- melt(dfTopMid)

contTabTopMid<-xtabs(value~Type+variable, datmTopMid)
CrossTable(contTabTopMid, fisher=TRUE, chisq=TRUE, expected=TRUE, sresid=TRUE, format="SPSS")

#Mid v Bottom
Bottom<-(df$Dog+df$Engine)/2
dfMidBot=data.frame(Type, Middle, Bottom)
datmMidBot <- melt(dfMidBot)

contTabMidBot<-xtabs(value~Type+variable, datmMidBot)
CrossTable(contTabMidBot, fisher=TRUE, chisq=TRUE, expected=TRUE, sresid=TRUE, format="SPSS")


#Just Dogs and Engines
datmBotDog<-subset(datm, datm$variable=="Dog")
datmBotEng<-subset(datm, datm$variable=="Engine")
datmBot<-rbind(datmBotEng,datmBotDog)

contTabBot<-xtabs(value~Type+droplevels(variable), datmBot)
CrossTable(contTabBot, fisher=TRUE, chisq=TRUE, expected=TRUE, sresid=TRUE, format="SPSS")

#plot top v mid v bottom
dfTopMidBot=data.frame(Type, Top, Middle, Bottom)

datmTopMidBot <- melt(dfTopMidBot)
datmTopMidBot$Type<-as.factor(datmTopMidBot$Type)

p7<-ggplot(datmTopMidBot,aes(x = variable, y = value,fill = Type)) + 
	geom_bar(position = "fill",stat = "identity") +

	scale_y_continuous(labels=percent_format())+
	theme_bw()+
	labs(x="Level", y="Percentage")+
	scale_fill_manual(values = c("Affect-judgement"="deepskyblue","Signal"="chartreuse4","Source"= "firebrick"))+
	theme(	
axis.title=title.text,
	axis.text=tick.text,
	legend.text=title.text,
	panel.grid	= element_blank(),
	legend.title=element_blank(),
	legend.background = element_rect(fill = "white")
)



#----------------------------- V and A plot

df=read.csv("F:/sound sorting data/wordTypes/myAffect_all.csv", header = TRUE, sep = ",")
head(df)
dfm<-melt(df)
head(dfm)
dfm$variable<-as.factor(dfm$variable)

Vdf<-subset(dfm, dfm$variable=="V")
Adf<-subset(dfm, dfm$variable=="A")
VAdf<-rbind(Vdf,Adf)
head(VAdf)

#myShapes<-c(16,17)
#names(myShapes)<-levels(VAdf$variable)
#colScaleShape <- scale_shape_manual(name = "variable",values = myShapes)


myCols<-c("deepskyblue","firebrick")
#names(myCols)<-levels(VAdf$variable)
colScaleCol <- scale_colour_manual(values = myCols)

VAdf$valueNorm<-VAdf$value-5

p2<-ggplot()+
stat_summary(data=VAdf, aes(x=Sound, y=valueNorm, group=variable, colour=variable),position=position_dodge(width=0.2),fun.data = mean_cl_boot, geom="errorbar", width=0.3,size=0.3)+
stat_summary(data=VAdf, aes(x=Sound, y=valueNorm, group=variable, colour=variable),position=position_dodge(width=0.2),fun.y=mean, geom="point",size=2.5)+
stat_summary(data=VAdf, aes(x=Sound, y=valueNorm, group=variable, colour=variable),position=position_dodge(width=0.2),fun.y=mean, geom="line")+
theme_bw()+
labs(x="Level", y="Score")+
#coord_cartesian(ylim = c(-2.5, 2.5))+
colScaleCol+
#colScaleShape+
#scale_colour_manual(values =c( "deepskyblue1","firebrick1"))+
theme(
	axis.title.x=title.text,
	axis.text.x=tick.text,

)

#--- SD of VA

VAdf<-VAdf[complete.cases(VAdf[ , 6]),]
ezANOVA(data=VAdf, dv=.(value), wid =.(wordList.k.), between=.(Sound), detailed=TRUE)

wilcox.test(Vdf$value[Vdf$Sound=="5_Engines"],Vdf$value[Vdf$Sound=="4_Dogs"], paired=FALSE)
wilcox.test(Vdf$value[Vdf$Sound=="2_Nature"],Vdf$value[Vdf$Sound=="1_Top"], paired=FALSE)

sdTopV<-sd(VAdf$value[VAdf$Sound=="1_Top" & VAdf$variable=="V"])
sdTopA<-sd(VAdf$value[VAdf$Sound=="1_Top" & VAdf$variable=="A"])
sdNatV<-sd(VAdf$value[VAdf$Sound=="2_Nature" & VAdf$variable=="V"])
sdNatA<-sd(VAdf$value[VAdf$Sound=="2_Nature" & VAdf$variable=="A"])
sdManV<-sd(VAdf$value[VAdf$Sound=="3_Manmade" & VAdf$variable=="V"])
sdManA<-sd(VAdf$value[VAdf$Sound=="3_Manmade" & VAdf$variable=="A"])
sdDogV<-sd(VAdf$value[VAdf$Sound=="4_Dogs" & VAdf$variable=="V"])
sdDogA<-sd(VAdf$value[VAdf$Sound=="4_Dogs" & VAdf$variable=="A"])
sdEngV<-sd(VAdf$value[VAdf$Sound=="5_Engines" & VAdf$variable=="V"])
sdEngA<-sd(VAdf$value[VAdf$Sound=="5_Engines" & VAdf$variable=="A"])

soundType<-cbind(c("Top", "Nature", "Mandmade", "Dogs", "Engines"))
sdV<-cbind(c(sdTopV, sdNatV, sdManV, sdDogV, sdEngV))
sdA<-cbind(c(sdTopA, sdNatA, sdManA, sdDogA, sdEngA))

dfBar<-data.frame(soundType, sdV, sdA)
dfBarm<-melt(dfBar)

p5<-ggplot(dfBarm, aes(soundType, value)) +   
  geom_bar(aes(fill = variable), position = "dodge", stat="identity")

#----- V and A scores of Affect Words only


df=read.csv("F:/sound sorting data/wordTypes/myAffect_all.csv", header = TRUE, sep = ",")
head(df)
dfm<-melt(df)
head(dfm)
dfm$variable<-as.factor(dfm$variable)

Vdf<-subset(dfm, dfm$variable=="V" & dfm$Type=="affect")
Adf<-subset(dfm, dfm$variable=="A" & dfm$Type=="affect")
VAdf<-rbind(Vdf,Adf)
head(VAdf)

#myShapes<-c(16,17)
#names(myShapes)<-levels(VAdf$variable)
#colScaleShape <- scale_shape_manual(name = "variable",values = myShapes)


#myCols<-c("deepskyblue","firebrick")
#names(myCols)<-levels(VAdf$variable)
#colScaleCol <- scale_colour_manual(name = "varable",values = myCols)

VAdf$valueNorm<-VAdf$value-5

p6<-ggplot()+
stat_summary(data=VAdf, aes(x=Sound, y=valueNorm, group=variable, colour=variable),position=position_dodge(width=0.2), fun.data = mean_cl_boot, geom="errorbar", width=0.3,size=0.3)+
stat_summary(data=VAdf, aes(x=Sound, y=valueNorm, group=variable, colour=variable),position=position_dodge(width=0.2),fun.y=mean, geom="point",size=2.5)+
stat_summary(data=VAdf, aes(x=Sound, y=valueNorm, group=variable, colour=variable ),position=position_dodge(width=0.2),fun.y=mean, geom="line")+
theme_bw()+
labs(x="Level", y="Score")+
#coord_cartesian(ylim = c(-2.5, 2.5))+
#colScaleCol+
#colScaleShape+
theme(
	axis.title.x=title.text,
	axis.text.x=tick.text,

)


# Abs V and A plot DONT USE


AbsVdf<-subset(dfm, dfm$variable=="Abs.V")
AbsAdf<-subset(dfm, dfm$variable=="Abs.A")
AbsVAdf<-rbind(AbsVdf,AbsAdf)
head(AbsVAdf)

myShapes<-c(16,17)
names(myShapes)<-levels(AbsVAdf$variable)
colScaleShape <- scale_shape_manual(name = "variable",values = myShapes)


myCols<-c("deepskyblue","firebrick")
names(myCols)<-levels(AbsVAdf$variable)
colScaleCol <- scale_colour_manual(name = "varable",values = myCols)


p3<-ggplot()+
stat_summary(data=AbsVAdf, aes(x=Sound, y=value, group=variable, colour=variable),fun.data = mean_cl_boot, geom="errorbar", width=0.3,size=0.3)+
stat_summary(data=AbsVAdf, aes(x=Sound, y=value, group=variable, colour=variable, shape=Type),fun.y=mean, geom="point",size=2.5)+
stat_summary(data=AbsVAdf, aes(x=Sound, y=value, group=variable, colour=variable),fun.y=mean, geom="line")+
theme_bw()+
labs(x="Level", y="Score")+
#coord_cartesian(ylim = c(-2.5, 2.5))+
colScaleCol+
colScaleShape+
theme(
	axis.title.x=title.text,
	axis.text.x=tick.text,

)

#----- vector distance from 5,5


Distdf<-subset(dfm, dfm$variable=="Distance")
head(Distdf)

p4<-ggplot()+
stat_summary(data=Distdf, aes(x=Sound, y=value),fun.data = mean_cl_boot, geom="errorbar", width=0.3,size=0.3)+
stat_summary(data=Distdf, aes(x=Sound, y=value),fun.y=mean, geom="point",size=2.5)+
stat_summary(data=Distdf, aes(x=Sound, y=value),fun.y=mean, geom="line")+
theme_bw()+
labs(x="Level", y="Score", main="Vector Distance")+
#coord_cartesian(ylim = c(-2.5, 2.5))+
#colScaleCol+
#colScaleShape+
theme(
	axis.title=title.text,
	axis.text=tick.text
)

setEPS()
postscript("wordtypes.eps", width=5, height=10)

grid.newpage()
pushViewport(viewport(layout = grid.layout(nrow=2, ncol=1)))

print(p7, vp = viewport(layout.pos.row = 1, layout.pos.col = 1))
grid.text("A", vp = viewport(layout.pos.row = 1, layout.pos.col = 1),y=0.98,x=0.02, gp=gpar(fontsize=15))
print(p1, vp = viewport(layout.pos.row = 2, layout.pos.col = 1))
grid.text("B", vp = viewport(layout.pos.row = 2, layout.pos.col = 1),y=0.98,x=0.02, gp=gpar(fontsize=15))

dev.off()

#----

setEPS()
postscript("VA.eps", width=10, height=10)

grid.newpage()
pushViewport(viewport(layout = grid.layout(nrow=2, ncol=2)))

print(p2, vp = viewport(layout.pos.row = 1, layout.pos.col = 1))
print(p5, vp = viewport(layout.pos.row = 1, layout.pos.col = 2))
print(p6, vp = viewport(layout.pos.row = 2, layout.pos.col = 1))
print(p4, vp = viewport(layout.pos.row = 2, layout.pos.col = 2))

dev.off()
